#if !defined PDCURSES_WINCON
    #include "wingui/pdcclip.c"
    #include "wingui/pdcdisp.c"
    #include "wingui/pdcgetsc.c"
    #include "wingui/pdckbd.c"
    #include "wingui/pdcscrn.c"
    #include "wingui/pdcsetsc.c"
    #include "wingui/pdcutil.c"
#endif